@@ -5,9 +5,9 @@ import os
 from slack import WebClient
 
 
-LOGGER_LEVEL = os.environ.get('LOGGER_LEVEL', 15)
-logger = logging.Logger("slack_client", level=LOGGER_LEVEL)
-logger.setLevel(LOGGER_LEVEL)
+SLACK_ENTITIES_LOGGER_LEVEL = int(os.environ.get('SLACK_ENTITIES_LOGGER_LEVEL', 15))
+logger = logging.Logger("slack_client", level=SLACK_ENTITIES_LOGGER_LEVEL)
+logger.setLevel(SLACK_ENTITIES_LOGGER_LEVEL)
 
 
 class SlackApiError(Exception):
@@ -32,7 +32,7 @@ class SlackClientWithLogging(WebClient):
         params[body_encoding] = kwargs
 
         response = super().api_call(**params)
-        logger.info(f"Response:\n {response}")
+        logger.info(f"Response: {response.status_code}.")
         return response
 
 
